@@ -43,7 +43,6 @@
 //! |tracing           | Support for Tracing middleware |
 //! |tempfile          | Support for [`tempfile`](https://crates.io/crates/tempfile) |
 //! |tower-compat      | Adapters for `tower::Layer` and `tower::Service`. |
-//! |lambda-http       | Support for AWS Lambda HTTP |
 
 #![forbid(unsafe_code)]
 #![deny(private_in_public, unreachable_pub)]
@@ -60,10 +59,6 @@ pub mod web;
 
 #[doc(inline)]
 pub use http;
-#[cfg(feature = "lambda_http")]
-#[cfg_attr(docsrs, doc(cfg(feature = "lambda_http")))]
-/// Support for AWS Lambda HTTP.
-pub mod lambda;
 
 mod body;
 mod request;
